@@ -332,7 +332,7 @@ class SvnCommand:
     def cmd_cat( self, args ):
         revision = args.getOptionalRevision( '--revision', 'head' )
         text = self.client.cat( args.getPositionalArgs( 1, 1 )[0], revision=revision )
-        print( text )
+        print( text.decode( 'utf-8' ) )
 
     def cmd_checkout( self, args ):
         recurse = args.getBooleanOption( '--non-recursive', False )
@@ -513,7 +513,7 @@ class SvnCommand:
             if info.rev:
                 print( 'Revision: %s' % info.rev.number )
             if info.repos_root_URL and self.pysvn_testing >= '01.03.00':
-                print( 'Repository root URL: %s' % info.repos_root_URL )
+                print( 'Repository root_URL: %s' % info.repos_root_URL )
             if info.repos_UUID:
                 print( 'Repository UUID: %s' % info.repos_UUID )
             if info.last_changed_author:
