@@ -9,21 +9,40 @@ sys.path.insert( 0, '../../Source')
 import pysvn
 import time
 
-os.system( 'uname -p >./uname-p.tmp' )
-processor = open( 'uname-p.tmp' ).read().strip()
-os.remove( 'uname-p.tmp' )
+os.system( 'lipo -info %s >lipo-info.tmp' % (sys.executable,) )
+lipo_info = open( 'lipo-info.tmp' ).read()
+os.remove( 'lipo-info.tmp' )
+
+is_x86_64 = 'x86_64' in lipo_info
+is_i386 = 'i386' in lipo_info
+
+if is_x86_64 and is_i386:
+    processor = 'intel'
+
+elif is_x86_64:
+    processor = 'x86_64'
+
+elif is_i386:
+    processor = 'i386'
+
+else:
+    assert False, 'Unknown processor type'
+
+vendor = os.environ.get( 'BUILDER_VENDOR', 'unknown' )
 
 if processor == 'i386':
     if hasattr( sys, 'maxsize' ):
         maxsize = sys.maxsize
     else:
         maxsize = sys.maxint
-
+    
     if maxsize == (2**31-1):
         processor = 'i386'
     else:
         processor = 'x86_64'
 
+python_vendor = os.environ[ 'BUILDER_VENDOR' ]
+
 pymaj, pymin, pypat, _, _ = sys.version_info
 python_version_string = '%d.%d.%d' % (pymaj, pymin, pypat)
 pysvnmaj, pysvnmin, pysvnpat, _ = pysvn.version
@@ -32,7 +51,7 @@ pysvn_short_version_string = '%d.%d.%d' % (pysvn.version[0], pysvn.version[1], p
 svn_version_package_string = '%d%d%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 svn_version_string = '%d.%d.%d' % (pysvn.svn_version[0], pysvn.svn_version[1], pysvn.svn_version[2])
 pysvn_so_string = '_pysvn_%d_%d.so' % (pymaj, pymin)
-pkg_filename = 'py%s%s_pysvn_svn%s-%s-%s' % (pymaj, pymin, svn_version_package_string, pysvn_version_string, processor)
+pkg_filename = 'py%s%s_%s_pysvn_svn%s-%s-%s' % (pymaj, pymin, vendor, svn_version_package_string, pysvn_version_string, processor)
 
 print( 'Info: Packageing %s' % pkg_filename )
 build_time  = time.time()
@@ -47,7 +66,13 @@ elif pymaj == 2 and pymin == 5:
     install_dir = '/Library/Frameworks/Python.framework/Versions/2.5/lib/python2.5/site-packages'
 
 elif pymaj == 2 and pymin == 6:
-    install_dir = '/Library/Frameworks/Python.framework/Versions/2.6/lib/python2.6/site-packages'
+    if vendor == 'apple_com':
+        install_dir = '/Library/Python/2.6/site-packages'
+    else:
+        install_dir = '/Library/Frameworks/Python.framework/Versions/2.6/lib/python2.6/site-packages'
+
+elif pymaj == 2 and pymin == 7:
+    install_dir = '/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/site-packages'
 
 elif pymaj == 3 and pymin == 1:
     install_dir = '/Library/Frameworks/Python.framework/Versions/3.1/lib/python3.1/site-packages'
@@ -174,9 +199,9 @@ f.write('''<?xml version="1.0" encoding="UTF-8"?>
 <plist version="1.0">
 <dict>
     <key>CFBundleGetInfoString</key>
-    <string>pysvn Extension %(pysvn_version_string)s</string>
+    <string>pysvn Extension %(pysvn_version_string)s for Python %(pymaj)s.%(pymin)s</string>
     <key>CFBundleIdentifier</key>
-    <string>org.tigris.pysvn.extension</string>
+    <string>org.tigris.pysvn.extension.py%(pymaj)s.%(pymin)s.%(python_vendor)s</string>
     <key>CFBundleName</key>
     <string>pysvn Extension</string>
     <key>CFBundleShortVersionString</key>
