@@ -349,7 +349,7 @@ public:
     pysvn_transaction( pysvn_module &module, Py::Dict result_wrappers );
     virtual ~pysvn_transaction();
     void init( const std::string &repos_path,
-        const std::string &transaction_name );
+        const std::string &transaction_name, bool is_revision );
 
     // override functions from PythonExtension
     virtual Py::Object getattr( const char *name );
@@ -359,6 +359,7 @@ public:
     // SVN Transaction commands
     Py::Object cmd_cat( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_changed( const Py::Tuple& args, const Py::Dict &kws );
+    Py::Object cmd_list( const Py::Tuple& args, const Py::Dict &kws );
 
     Py::Object cmd_propdel( const Py::Tuple& args, const Py::Dict &kws );
     Py::Object cmd_propget( const Py::Tuple& args, const Py::Dict &kws );
@@ -623,7 +624,7 @@ public:
             case Py_GE:
                 return Py::Boolean( m_value >= other_value->m_value );
             default:
-            throw Py::RuntimeError( "rich_compare bad op" );
+                throw Py::RuntimeError( "rich_compare bad op" );
             }
         }
         else
@@ -631,7 +632,7 @@ public:
             std::string msg( "expecting " );
             msg += toTypeName( m_value );
             msg += " object for rich compare ";
-            throw Py::AttributeError( msg );
+            throw Py::NotImplementedError( msg );
         }
     }
 
@@ -791,6 +792,7 @@ extern apr_array_header_t *targetsFromStringOrList( Py::Object arg, SvnPool &poo
 extern Py::List toListOfStrings( Py::Object obj );
 extern apr_array_header_t *arrayOfStringsFromListOfStrings( Py::Object arg, SvnPool &pool );
 extern apr_hash_t *hashOfStringsFromDistOfStrings( Py::Object arg, SvnPool &pool );
+extern Py::Object direntsToObject( apr_hash_t *props, SvnPool &pool );
 
 Py::Object toObject( apr_time_t t );
 Py::Object toObject( pysvn_commit_info_t *commit_info, int commit_style );
