@@ -49,10 +49,12 @@ pysvn_transaction::pysvn_transaction
 void pysvn_transaction::init
     (
     const std::string &repos_path,
-    const std::string &transaction_name
+    const std::string &transaction_name,
+    bool is_revision
     )
 {
-    svn_error_t *error = m_transaction.init( repos_path, transaction_name );
+    svn_error_t *error = m_transaction.init( repos_path, transaction_name,
+        is_revision );
     if( error != NULL )
     {
         SvnException e( error );
@@ -138,7 +140,7 @@ Py::Object pysvn_transaction::cmd_cat( const Py::Tuple &a_args, const Py::Dict &
         svn_error_t *error;
 
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -188,11 +190,23 @@ Py::Object pysvn_transaction::cmd_changed( const Py::Tuple &a_args, const Py::Di
 
     try
     {
-        svn_revnum_t base_rev = svn_fs_txn_base_revision( m_transaction );
-        if( !SVN_IS_VALID_REVNUM( base_rev ) )
-            throw Py::RuntimeError( "svn_fs_txn_base_revision failed" );
-
         svn_error_t *error;
+        svn_revnum_t base_rev;
+        if( m_transaction.is_revision() )
+        {
+            base_rev = m_transaction.revision() - 1;
+        }
+        else
+        {
+            base_rev = svn_fs_txn_base_revision( m_transaction );
+        }
+        if( !SVN_IS_VALID_REVNUM( base_rev ) )
+        {
+            error = svn_error_create( SVN_ERR_FS_NO_SUCH_REVISION,
+                NULL, "Transaction is not based on a revision" );
+            throw SvnException( error );
+        }
+
         // Get the base root.
         svn_fs_root_t *base_rev_root = NULL;
         error = svn_fs_revision_root( &base_rev_root, m_transaction, base_rev, pool );
@@ -200,7 +214,7 @@ Py::Object pysvn_transaction::cmd_changed( const Py::Tuple &a_args, const Py::Di
             throw SvnException( error );
 
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -230,6 +244,61 @@ Py::Object pysvn_transaction::cmd_changed( const Py::Tuple &a_args, const Py::Di
     return dict;
 }
 
+Py::Object pysvn_transaction::cmd_list( const Py::Tuple &a_args, const Py::Dict &a_kws )
+{
+    static argument_description args_desc[] =
+    {
+    { false,  name_path },
+    { false, NULL }
+    };
+    FunctionArguments args( "list", args_desc, a_args, a_kws );
+    args.check();
+
+    std::string path( args.getUtf8String( name_path, empty_string ) );
+
+    SvnPool pool( m_transaction );
+
+    apr_hash_t *dir_entries = NULL;
+
+    try
+    {
+        svn_error_t *error;
+
+        svn_fs_root_t *txn_root = NULL;
+        error = m_transaction.root( &txn_root, pool );
+        if( error != NULL )
+            throw SvnException( error );
+
+        svn_node_kind_t kind;
+        error = svn_fs_check_path( &kind, txn_root, path.c_str(), pool );
+        if( error != NULL )
+            throw SvnException( error );
+
+        if( kind == svn_node_none )
+        {
+            error = svn_error_createf( SVN_ERR_FS_NOT_FOUND, NULL, "Path '%s' does not exist", path.c_str() );
+            throw SvnException( error );
+        }
+
+        if( kind != svn_node_dir )
+        {
+            error = svn_error_createf( SVN_ERR_FS_NOT_DIRECTORY, NULL, "Path '%s' is not a directory", path.c_str() );
+            throw SvnException( error );
+        }
+
+        error = svn_fs_dir_entries( &dir_entries, txn_root, path.c_str(), pool );
+        if( error != NULL )
+            throw SvnException( error );
+
+    }
+    catch( SvnException &e )
+    {
+        throw_client_error( e );
+    }
+
+    return direntsToObject( dir_entries, pool );
+}
+
 #if 0
 Py::Object pysvn_transaction::cmd_diff( const Py::Tuple &a_args, const Py::Dict &a_kws )
 {
@@ -266,7 +335,7 @@ Py::Object pysvn_transaction::cmd_propdel( const Py::Tuple &a_args, const Py::Di
         svn_error_t * error;
 
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -322,7 +391,7 @@ Py::Object pysvn_transaction::cmd_propget( const Py::Tuple &a_args, const Py::Di
     {
         svn_error_t * error;
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -376,7 +445,7 @@ Py::Object pysvn_transaction::cmd_proplist( const Py::Tuple &a_args, const Py::D
     {
         svn_error_t * error;
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -426,7 +495,7 @@ Py::Object pysvn_transaction::cmd_propset( const Py::Tuple &a_args, const Py::Di
         svn_error_t * error;
 
         svn_fs_root_t *txn_root = NULL;
-        error = svn_fs_txn_root( &txn_root, m_transaction, pool );
+        error = m_transaction.root( &txn_root, pool );
         if( error != NULL )
             throw SvnException( error );
 
@@ -478,13 +547,28 @@ Py::Object pysvn_transaction::cmd_revpropdel( const Py::Tuple &a_args, const Py:
 
     try
     {
-        svn_error_t *error = svn_fs_change_txn_prop
-            (
-            m_transaction,
-            prop_name.c_str(),
-            NULL,            // value = NULL
-            pool
-            );
+        svn_error_t *error;
+        if( m_transaction.is_revision() )
+        {
+            error = svn_fs_change_rev_prop
+                (
+                m_transaction,
+                m_transaction.revision(),
+                prop_name.c_str(),
+                NULL,            // value = NULL
+                pool
+                );
+        }
+        else
+        {
+            error = svn_fs_change_txn_prop
+                (
+                m_transaction,
+                prop_name.c_str(),
+                NULL,            // value = NULL
+                pool
+                );
+        }
         if( error != NULL )
             throw SvnException( error );
     }
@@ -514,7 +598,28 @@ Py::Object pysvn_transaction::cmd_revpropget( const Py::Tuple &a_args, const Py:
 
     try
     {
-        svn_error_t * error = svn_fs_txn_prop( &prop_val, m_transaction, prop_name.c_str(), pool );
+        svn_error_t *error;
+        if( m_transaction.is_revision() )
+        {
+            error = svn_fs_revision_prop
+                (
+                &prop_val,
+                m_transaction,
+                m_transaction.revision(),
+                prop_name.c_str(),
+                pool
+                );
+        }
+        else
+        {
+            error = svn_fs_txn_prop
+                (
+                &prop_val,
+                m_transaction,
+                prop_name.c_str(),
+                pool
+                );
+        }
         if( error != NULL )
             throw SvnException( error );
     }
@@ -548,12 +653,26 @@ Py::Object pysvn_transaction::cmd_revproplist( const Py::Tuple &a_args, const Py
 
     try
     {
-        svn_error_t *error = svn_fs_txn_proplist
-            (
-            &props,
-            m_transaction,
-            pool
-            );
+        svn_error_t *error;
+        if( m_transaction.is_revision() )
+        {
+            error = svn_fs_revision_proplist
+                (
+                &props,
+                m_transaction,
+                m_transaction.revision(),
+                pool
+                );
+        }
+        else
+        {
+            error = svn_fs_txn_proplist
+                (
+                &props,
+                m_transaction,
+                pool
+                );
+        }
         if( error != NULL )
             throw SvnException( error );
     }
@@ -584,13 +703,28 @@ Py::Object pysvn_transaction::cmd_revpropset( const Py::Tuple &a_args, const Py:
     try
     {
         const svn_string_t *svn_prop_val = svn_string_ncreate( prop_val.c_str(), prop_val.size(), pool );
-        svn_error_t *error = svn_fs_change_txn_prop
-            (
-            m_transaction,
-            prop_name.c_str(),
-            svn_prop_val,
-            pool
-            );
+        svn_error_t *error;
+        if( m_transaction.is_revision() )
+        {
+            error = svn_fs_change_rev_prop
+                (
+                m_transaction,
+                m_transaction.revision(),
+                prop_name.c_str(),
+                svn_prop_val,
+                pool
+                );
+        }
+        else
+        {
+            error = svn_fs_change_txn_prop
+                (
+                m_transaction,
+                prop_name.c_str(),
+                svn_prop_val,
+                pool
+                );
+        }
         if( error != NULL )
             throw SvnException( error );
     }
@@ -612,6 +746,7 @@ void pysvn_transaction::init_type()
 
     add_keyword_method("cat", &pysvn_transaction::cmd_cat, pysvn_transaction_cat_doc );
     add_keyword_method("changed", &pysvn_transaction::cmd_changed, pysvn_transaction_changed_doc );
+    add_keyword_method("list", &pysvn_transaction::cmd_list, pysvn_transaction_list_doc );
 #if 0
     add_keyword_method("diff", &pysvn_transaction::cmd_diff, pysvn_transaction_diff_doc );
 #endif
