@@ -1,6 +1,6 @@
 #
 # ====================================================================
-# (c) 2005-2009 Barry A Scott.  All rights reserved.
+# Copyright (c) 2005-2010 Barry A Scott.  All rights reserved.
 #
 # This software is licensed as described in the file LICENSE.txt,
 # which you should have received as part of this distribution.
@@ -16,6 +16,7 @@ import sys
 import os
 import distutils
 import distutils.sysconfig
+import distutils.util
 
 import xml.dom.minidom
 import xml.sax
@@ -23,6 +24,9 @@ import xml.sax
 class SetupError(Exception):
     pass
 
+# version of PyCXX that we require
+pycxx_version = (6, 2, 2)
+
 
 all_options_info = {
     '--arch':               (2, '<arch>'),
@@ -37,6 +41,7 @@ all_options_info = {
     '--pycxx-src-dir':      (1, '<dir>'),
     '--svn-inc-dir':        (1, '<dir>'),
     '--svn-lib-dir':        (1, '<dir>'),
+    '--svn-bin-dir':        (1, '<dir>'),
     '--svn-root-dir':       (1, '<dir>'),
     '--verbose':            (0, None),
     }
@@ -185,7 +190,7 @@ class MakeFileCreater:
 
         if self.is_mac_os_x and self.hasOption( '--arch' ):
             print( 'Info: Building for arch %s' % ', '.join( self.getOption( '--arch' ) ) )
-            self.mac_os_x_arch = ', '.join( ['-arch %s' % (arch,) for arch in self.getOption( '--arch' )] )
+            self.mac_os_x_arch = ' '.join( ['-arch %s' % (arch,) for arch in self.getOption( '--arch' )] )
         else:
             self.mac_os_x_arch = ''
 
@@ -264,6 +269,13 @@ class MakeFileCreater:
                 py_cflags_list.append( '-Dinit_pysvn=init_pysvn_%d_%d' % sys.version_info[:2] )
                 py_cflags_list.append( '-Dinit_pysvn_d=init_pysvn_%d_%d_d' % sys.version_info[:2] )
 
+
+        pysvn_version_info = {}
+        f = open( '../Builder/version.info', 'r' )
+        for line in f:
+            key, value = line.strip().split('=')
+            pysvn_version_info[ key ] = value
+
         template_values = {
             'pysvn_module_name': pysvn_module_name,
 
@@ -297,6 +309,15 @@ class MakeFileCreater:
             # pycxx src dir
             'pycxx_src_dir':    pycxx_src_dir,
 
+            # python version:
+            'python_version':   '%d.%d' % (sys.version_info[0], sys.version_info[1]),
+
+            # python platform:
+            'python_platform':  distutils.util.get_platform(),
+
+            # pysvn version:
+            'pysvn_version':    '%(MAJOR)s.%(MINOR)s.%(PATCH)s' % pysvn_version_info,
+
             # mac arch options
             'mac_os_x_arch':    self.mac_os_x_arch
             }
@@ -318,13 +339,21 @@ class MakeFileCreater:
             var_ldlibrary = distutils.sysconfig.get_config_var('LDLIBRARY')
             framework_lib = os.path.join( var_prefix, os.path.basename( var_ldlibrary ) )
 
-            if self.is_atleast_mac_os_x_version( (10,4) ) >= 0:
+            if self.is_atleast_mac_os_x_version( (10,5) ) >= 0:
+                if self.verbose:
+                    print( 'Info: Using Mac OS X 10.5 makefile template' )
+
+                template_values['extra_libs'] = ''
+                template_values['frameworks'] = '-framework System %s -framework CoreFoundation -framework Kerberos -framework Security' % framework_lib
+
+            elif self.is_atleast_mac_os_x_version( (10,4) ) >= 0:
                 if self.verbose:
                     print( 'Info: Using Mac OS X 10.4 makefile template' )
 
                 # 10.4 needs the libintl.a but 10.3 does not
                 template_values['extra_libs'] = '%(svn_lib_dir)s/libintl.a' % template_values
                 template_values['frameworks'] = '-framework System %s -framework CoreFoundation -framework Kerberos -framework Security' % framework_lib
+
             else:
                 if self.verbose:
                     print( 'Info: Using Mac OS X 10.3 makefile template' )
@@ -477,7 +506,7 @@ LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,%(svn_lib_dir)s \
 -lsvn_client-1 \
 -lsvn_diff-1 \
 -lsvn_repos-1 \
--lcom_err -lresolv -lexpat -lneon -lssl
+-lcom_err -lresolv -lexpat -lssl
 PYSVN_CREATE_INIT_OPTION=%(pysvn_module_name)s
 
 #include pysvn_common.mak
@@ -522,8 +551,12 @@ LDSHARED=g++ -shared %(debug_cflags)s
 LDLIBS=-L%(svn_lib_dir)s -Wl,--rpath -Wl,/usr/lib:/usr/local/lib:%(svn_lib_dir)s \
 -lsvn_client-1 \
 -lsvn_diff-1 \
--lsvn_repos-1 \
- -lkrb5 -lcom_err -lexpat -lneon
+-lsvn_repos-1
+
+.if exists(/usr/lib/libkrb5.so)
+LDLIBS+=-lkrb5
+.endif
+LDLIBS+=-lcom_err -lexpat -lneon
 
 #include pysvn_common.mak
 '''
@@ -740,8 +773,6 @@ LDLIBS= \
 '''
 
     def find_pycxx( self ):
-        pycxx_version = (6, 1, 1)
-
         pycxx_dir = self.find_dir(
                     'PyCXX include',
                     '--pycxx-dir',
@@ -760,14 +791,13 @@ LDLIBS= \
             if 'PYCXX_VERSION_MAJOR' in words:
                 major_match = int( words[2] ) == pycxx_version[0]
             if 'PYCXX_VERSION_MINOR' in words:
-                minor_match = int( words[2] ) == pycxx_version[0]
+                minor_match = int( words[2] ) == pycxx_version[1]
 
         if not major_match and not minor_match:
             raise SetupError( 'PyCXX version not as required.' )
 
         return pycxx_dir
 
-
     def find_pycxx_src( self, pycxx_dir ):
         return self.find_dir(
                     'PyCXX Source',
